# Simple and Effective Exit Trading Strategies

| Author       | Source       | 
| :-------------: |:-------------:|
|  [Alan Farley](https://www.investopedia.com/contributors/53687/) | [Investopedia](https://www.investopedia.com/articles/active-trading/020915/mustknow-simple-effective-exit-trading-strategies.asp) | 

---

Traders spend hours fine-tuning entry strategies but then blow out their accounts taking bad exits. In fact, most of us lack [effective exit planning](https://www.investopedia.com/investing/understanding-exit-strategies/), often getting shaken out at the worst possible price. We can remedy this oversight with classic strategies that can enhance profitability. Before we jump into the strategies, we'll start with a look at why the holding period is so important. Then we'll move into the misunderstood concept of [market timing](https://www.investopedia.com/terms/m/markettiming.asp), then move on to stop and scaling methods that protect profits and reduce losses.

### KEY TAKEAWAYS

-   Many traders design strong exit strategies, but then don't follow through when the time comes to take action; the results can be devastating.
-   When making your plan, start by calculating reward and risk levels prior to entering a trade, then use those levels as a blueprint to exit the position at the best price, whether you're profiting or taking a loss.
-   Market timing, an often misunderstood concept, is a good exit strategy when used correctly.
-   Stop-loss and scaling methods also enable savvy, methodical investors to protect profits and reduce losses.

Holding Periods
---------------

It's impossible to talk about exits without noting the importance of a [holding period](https://www.investopedia.com/terms/h/holdingperiod.asp) that synergizes well with your trading strategy. The magic time frames roughly align with the broad approach chosen to take money out of the financial markets:

-   [Day Trading](https://www.investopedia.com/terms/d/daytrader.asp): Minutes to Hours
-   [Swing](https://www.investopedia.com/terms/s/swingtrading.asp) Trading: Hours to Days
-   [Position](https://www.investopedia.com/terms/p/positiontrader.asp) Trading: Days to Weeks
-   [Investment](https://www.investopedia.com/terms/i/investing.asp) Timing: Weeks to Months

Pick the category that aligns most closely with your market approach, as this dictates how long you have to book your profit or loss. Stick to the parameters, or you'll risk [turning a trade into an investment](https://www.investopedia.com/ask/answers/12/difference-investing-trading.asp) or a [momentum](https://www.investopedia.com/terms/m/momentum.asp) play into a [scalp](https://www.investopedia.com/terms/s/scalping.asp). This approach requires discipline because some positions perform so well that you want to keep them beyond time constraints. While you can stretch and squeeze a holding period to account for market conditions, taking your exit within parameters builds confidence, profitability, and trading skill. 

Market Timing
-------------

Get into the habit of establishing reward and risk targets before entering each trade. Look at the chart and find the next [resistance](https://www.investopedia.com/terms/r/resistance.asp) level likely to come into play within the time constraints of your holding period. That marks the reward target. Then find the price where you'll be proven wrong if the security turns and hits it. That's your risk target. Now calculate the [reward/risk ratio](https://www.investopedia.com/terms/r/riskrewardratio.asp), looking for at least 2:1 in your favor. Anything less, and you should skip the trade, moving on to a better opportunity.

Focus trade management on the two key exit prices. Let's assume things are going your way and the advancing price is moving toward your reward target. The price[ rate of change](https://www.investopedia.com/terms/p/pricerateofchange.asp) now comes into play because the faster it gets to the magic number, the more flexibility you have in choosing a favorable exit. Your first [option](https://www.investopedia.com/terms/e/exit-option.asp) is to take a blind exit at the price, pat yourself on the back for a job well done and move on to the next trade. A better option when the price is trending strongly in your favor is to let it exceed the reward target, placing a [protective stop](https://www.investopedia.com/terms/p/protectivestop.asp) at that level while you attempt to add to gains. Then look for the next obvious barrier, staying positioned as long as it doesn't violate your holding period.

Slow advances are trickier to trade because many [securities](https://www.investopedia.com/terms/s/security.asp) will approach but not reach the reward target. This requires a [profit protection strategy](https://www.investopedia.com/articles/trading/09/buy-stop-sell-stop-limit.asp) that kicks into gear once the price has traversed 75% of the distance between your risk and reward targets. Place a [trailing stop](https://www.investopedia.com/terms/t/trailingstop.asp) that protects partial gains or, if you're trading in real-time, keep one finger on the exit button while you watch the [ticker](https://www.investopedia.com/terms/t/tickertape.asp). The trick is to stay positioned until [price action](https://www.investopedia.com/terms/p/price-action.asp) gives you a reason to get out. 

![Image](https://www.investopedia.com/thmb/dr-Y-xsGZcy90q1lhdXZLChpB78=/4209x3964/filters:no_upscale():max_bytes(150000):strip_icc():format(webp)/dotdash_Final_Simple_and_Effective_Exit_Trading_Strategies_Sep_2020-01-86bda659603341aa92b56808b2bd8682.jpg)

Image by Sabrina Jiang © Investopedia 2020

In this example, Electronic Arts Inc. ([EA](https://www.investopedia.com/markets/quote?tvwidgetsymbol=ea)) stock [sells off](https://www.investopedia.com/terms/s/sell-off.asp) in October, undercutting the August low. It remounts [support](https://www.investopedia.com/terms/s/support.asp) two days later, issuing a *2B Buy* signal, as defined in the 1993 classic "Trader Vic: Methods of a Wall Street Master." The trader calculates reward/risk as follows, planning an entry near $34 and a [stop-loss](https://www.investopedia.com/terms/s/stop-lossorder.asp) just below the new support level:

-   REWARD TARGET (38.39) - RISK TARGET(32.60) = 5.79
-   REWARD = REWARD TARGET (38.39) - ENTRY (34) = 4.39
-   RISK = ENTRY (34) - RISK TARGET(32.60) = 1.40
-   REWARD (4.39) / RISK (1.40) = 3.13

The position goes better than expected, [gapping](https://www.investopedia.com/terms/g/gap.asp) above the reward target. The trader responds with a profit protection stop right at the reward target, raising it nightly as long the upside makes additional progress. (See also: *[Playing the Gap](https://www.investopedia.com/articles/trading/05/playinggaps.asp).*)

An effective exit strategy builds confidence, trade management skills and profitability.

Stop Loss Strategies
--------------------

Stops need to go where they get you out when a security violates the technical reason you took the trade. This is a confusing concept for traders who have been taught to [place stops](https://www.investopedia.com/video/play/stop-loss-order-strategy/) based on arbitrary values, like a 5% [drawdown](https://www.investopedia.com/terms/d/drawdown.asp) or $1.50 under the entry price. These placements make no sense because they aren't tuned to the characteristics and [volatility](https://www.investopedia.com/terms/v/volatility.asp) of that particular instrument. Instead, use violations of technical features---like [trendlines](https://www.investopedia.com/terms/t/trendline.asp), round numbers and [moving averages](https://www.investopedia.com/terms/m/movingaverage.asp)---to establish the natural stop-loss price.

![Image](https://www.investopedia.com/thmb/YM2b5FUG16Z07hvCqpqJivHgM7g=/4209x3963/filters:no_upscale():max_bytes(150000):strip_icc():format(webp)/dotdash_Final_Simple_and_Effective_Exit_Trading_Strategies_Sep_2020-02-2f68c020406d479b9fbf74cbee41f409.jpg)

Image by Sabrina Jiang © Investopedia 2020

In this example, Alcoa Corporation ([AA](https://www.investopedia.com/markets/quote?tvwidgetsymbol=aa)) stock rips higher in a steady [uptrend](https://www.investopedia.com/terms/u/uptrend.asp). It stalls above $17 and pulls back to a three-month trendline. The subsequent bounce returns to the high, encouraging the trader to enter a [long position](https://www.investopedia.com/terms/l/long.asp), in anticipation of a [breakout](https://www.investopedia.com/terms/b/breakout.asp). Common sense dictates that a [trendline break](https://www.investopedia.com/articles/trading/06/trendlines.asp) will prove the rally thesis wrong, demanding an immediate exit. In addition, the 20-day [simple moving average](https://www.investopedia.com/terms/s/sma.asp) (SMA) has aligned with the trendline, raising the odds that a violation will attract additional selling pressure.

Modern markets require an additional step in effective stop placement. [Algorithms](https://www.investopedia.com/terms/a/algorithm.asp) now routinely target common stop-loss levels, shaking out retail players, and then jumping back across support or resistance. This requires that stops be placed away from the numbers that say you're wrong and need to get out. Finding the perfect price to avoid these *stop runs* is more art than science. As a general rule, an additional 10 to 15 cents should work on a low-volatility trade, while a momentum play may require an additional 50 to 75 cents. You have more options when watching in real-time because you can exit at your original risk target, re-entering if the price jumps back across the contested level.

Scaling Exit Strategies
-----------------------

For a [scaling exit approach](https://www.investopedia.com/terms/r/risk-control.asp), raise your stop to break even as soon as a new trade moves into a profit. This can build confidence because you now have a free trade. Then sit back and let it run until the price reaches 75% of the distance between risk and reward targets. You then have the option to exit all at once or in pieces. This decision tracks position size as well as the strategy being employed. For example, it makes no sense to break a small trade into even smaller parts, so it is more effective to seek the most opportune moment to dump the entire stake or apply the stop-at-reward strategy. 

Larger positions benefit with a tiered exit strategy, exiting one third at 75% of the distance between risk and reward targets and the second third at the target. Place a trailing stop behind the third piece after it exceeds the target, using that level as a rock-bottom exit if the position turns south. Over time, you'll find this third piece is a lifesaver, often generating a substantial profit. Finally, consider one exception to this tiered strategy. Sometimes the market hands out gifts, and it;'s our job to pick the [low-hanging fruit](https://www.investopedia.com/terms/l/low-hanging-fruit.asp). So, when a news shock triggers a sizable gap in your direction, exit the entire position immediately and without regret, following the old wisdom: Never looks a gift horse in the mouth.
