# Trading exit strategies: a complete guide for traders

| Author       | Source       | 
| :-------------: |:-------------:|
| [Becca Cattlin](https://www.ig.com/en/profile/becca-cattlin)| [ig.com](https://www.ig.com/en/trading-strategies/trading-exit-strategies--a-complete-guide-for-traders-210208) | 

---


## There are two ways to exit a trade: taking a profit and taking a loss. Discover how to manage your trades to reduce your risk of exiting a trade with losses.

![Chart](https://a.c-dn.net/c/content/dam/publicsites/igcom/uk/images/news-article-image-folder/BG%20trader%20chart%20data%20304970815.jpg)

Why do you need an exit strategy in trading?
--------------------------------------------

You need an exit strategy to ensure you stick to the decisions you've outlined in your [trading plan](https://www.ig.com/en/trading-strategies/how-to-create-a-successful-trading-plan-181210). Without a plan, you're more likely to make decisions based on emotions -- such as fear and greed -- which could lead you to take profits prematurely or run your losses.

[Learn more about ](http://www.ig.com/uk/research/psychology-in-trading)[trading psychology](https://www.ig.com/uk/research/psychology-in-trading)

By having an understanding of what exit you're going to make, you'll be able to minimise your [risks](https://www.ig.com/en/risk-management) and have a higher chance of locking in profits.

How to exit a trade
-------------------

1.  Log in to your [account](https://www.ig.com/en/application-form) and open the platform
2.  Monitor your trade in the positions tab on the left-hand side menu
3.  Identify your exit point using [fundamental analysis](https://www.ig.com/en/trading-strategies/beginners-guide-to-fundamental-analysis-190503) and [technical analysis](https://www.ig.com/en/trading-strategies/beginners-guide-to-technical-analysis-190430)
4.  Exit your position manually by selecting 'close' or use an order

### How to exit a trade using a stop-loss order

A [stop-loss](https://www.ig.com/en/trading-strategies/stop-vs-limit-orders-what-are-the-types-of-orders-in-trading-190509) is an order that enables you to automatically exit a trade at a pre-determined level that is less favourable than the current market price. For long positions, this level is lower than the price you entered the market, and for short positions, it will be higher.

For example, you take a spread betting position on [gold](https://www.ig.com/en/commodities/gold-trading) at 1840 for £5 per point of movement. When you entered the trade, you attached a stop-order at 1740. This means if the market moved against you by 100 points, so the most you could lose is £500 and your trade would automatically close.

![stop-loss](https://a.c-dn.net/c/content/dam/publicsites/igcom/uk/images/ContentImage/mde-5175-stop-loss-08022021.png)

Stop-losses can help you manage your risk in a quickly moving market, by essentially pulling the plug on your trade if you lose a certain amount of money. The danger of stop-losses is that they can be subject to slippage -- which is the market moves in the time it takes your broker to execute the order.

This is the most basic type of stop-loss, but there are different types that you could use, such as:

-   Guaranteed stops -- these ensure your position is always closed at your pre-selected price, eradicating the risk of slippage. They're free to attach, but you'll be charged a small premium if it's triggered
-   [Trailing stops](https://www.ig.com/en/glossary-trading-terms/trailing-stops-definition) -- this type of stop follows the market if it moves in your favour, but locks in if the market moves against you. For example, if you choose a step size of ten, every time the market moves up by five points, your stop will move five points to follow it

### How to exit a trade using a take-profit orders

Take-profit orders, also known as [limit](https://www.ig.com/en/glossary-trading-terms/limit-order-definition)-close orders, are similar to stop-losses in that they close your trade at a pre-determined price level. Unlike limit-close orders, they are executed at a price more favourable to you than the current market price.

For a long position, the exit point has to be set above the current market price and for a short position, the exit point will be set below the market price. This means they can be used to lock in profit for you.

For example, say Brent crude [oil](https://www.ig.com/en/commodities/oil) is currently trading at $63.50. Your technical analysis has shown that $60.00 is a significant support level for this market, suggesting that if it hits this price it will rebound and start rising again.

You decide to open a short position, selling Brent crude and place a stop-entry order at $60.00. Two hours later, and the market reaches this level, so your broker executes your stop and closes your position. This means you would have locked in a certain amount of profit.

![take profit chart](https://a.c-dn.net/c/content/dam/publicsites/igcom/uk/images/ContentImage/mde-5175-take-profit_08022021.png)

While take-profit orders can be a great way to secure a positive upside, without a stop-loss order attached too, you'd have a potentially unlimited downside on your trade.

What to consider in your exit strategy?
---------------------------------------

Before you create an exit strategy, you'll need to consider your:

-   Trading style
-   Risk-reward ratio
-   Risk tolerance

### Trading style

Your exit strategy will completely depend on the [style](https://www.ig.com/en/trading-strategies/the-complete-guide-to-trading-strategies-and-styles-190709) of trading you choose. Your preferences will determine how often you'll trade and how long you'll hold a position for. There are four popular trading styles:

1.  [Position trading](https://www.ig.com/en/trading-strategies/best-position-trading-strategies-200717)\
    Position traders will hold positions for long periods of time to take advantage of an overarching market trend. The most well-known type of position trading is investing or a 'buy and hold' tactic. In this case, your exit strategy would need to ignore shorter-term market fluctuations and focus on letting profits run
2.  [Swing trading](https://www.ig.com/en/trading-strategies/swing-trading-strategies--a-beginners-guide-190712)\
    Swing trading focuses on spotting a trend early, then using the peaks and troughs to identify entry and exit points. A swing low would be a chance to enter a long position and exit a short position, while a swing high would be the time to exit a long position and enter a short position
3.  Day trading\
    Day traders will enter and exit trades within a single day to profit from short-term market movements. Exiting trades before the market closes each evening can help to avoid the risks and costs associated with overnight funding of a trade. Swing trading and scalping can also be classified as day trading, as they often also take place in a single day
4.  [Scalping](https://www.ig.com/en/trading-strategies/four-simple-scalping-trading-strategies-190131)\
    ​Scalpers will have the shortest amount of time between entering and exiting their trades -- often only a few seconds or minutes. The goal is to make small but frequent profits that will stack up over time. This style requires the most time and focus

### Risk-reward ratio

When you're planning your exit strategy, you'll need to consider your risk-reward ratio (RRR). This shows you how much capital you'd be willing to lose compared to the profit you would earn on the trade. The most common RRRs are 1:2 or 1:3, as 1:1 is considered too risky.

Say your potential loss on a trade is £200 and your maximum gain is £600, then your RRR is 1:3. This means that over the course of ten trades, you could have made £400 despite only being right 30% of the time.

![Reward chart](https://a.c-dn.net/c/content/dam/publicsites/igcom/uk/images/ContentImage/mde-5175-strategy-08022021.png)

Knowing your risk-reward ratio will enable you to have a better understanding of the potential risks you'll need to take on in order to reach your profit target.

[Learn more about the risk-reward ratio with IG Academy](https://www.ig.com/en/learn-to-trade/ig-academy/money-management)

### Risk tolerance

This brings us on to your risk tolerance, which is your attitude toward -- and ability to handle -- loss. It's important to know your own risk tolerances because if you take on too much risk you could panic and exit your position too early or too late.

Attaching stops is a key part of regulating your risk tolerance, as it enables you to automate your risk management. You can predetermine how much capital you're willing to put at risk and set a stop at that level. This gives you peace of mind that your losses can't run longer than you're comfortable with.

### Three exit strategies you should know

There are lots of different methodologies that you can use to determine when the right time to exit a trade is. These are three of the most common:

1.  Support and resistance\
    [Support and resistance](https://www.ig.com/en/trading-strategies/support-and-resistance-levels-explained-181219) levels show levels at which the market finds a limit on movement. Support levels indicate a price low -- a floor -- that would be considered oversold and cause buyers to flood the market. A resistance level is a price high -- a ceiling -- that is considered overbought, which buyers are unwilling to pay and so start closing their positions, pushing price lower.

    Trends often reverse at these levels, which is why we tend to see stop-loss orders and limit-close orders around these levels. Taking profit and loss around these levels is very common, to the point support and resistance levels are known as self-fulfilling prophecies -- people expect markets to change at these levels, so they inevitably do.

    So, if you were in a long position, you could take profit at a resistance level and set your stop-loss at a known support level -- and vice versa for a short position.

    Support and resistance levels can be identified using a range of different indicators, such as moving averages, [Fibonacci retracements](https://www.ig.com/en/glossary-trading-terms/fibonacci-retracement-definition) and pivot points.
2.  Moving averages\
    [Moving averages (MAs)](https://www.ig.com/en/trading-strategies/moving-averages--how-to-calculate-them-and-use-them-in-your-trad-181008) use data to find trends and smooth out price action by filtering out random fluctuations caused by volatility.

    To calculate the MA, you simply add up the set of numbers and divide by the total number of values in the set. For example, if you wanted to calculate the moving average of a five-year period, you would add up the numbers over that period, and then divide by five. The most common MAs are the 50 or 200-day.

    The basic idea is that when the price is above a moving average, there could be a buying opportunity, and when the price is below a moving average, there could be a selling opportunity. However, it can also be useful to consider a moving average as a trailing stop. As the price rises or falls, so will the MA -- meaning you can move your stop to where the MA is and it will create a sort of safety net should the price move against you.
3.  Average true range\
    The [average true range (ATR)](https://www.ig.com/en/trading-strategies/trading-with-the-average-true-range-indicator-191114) indicator tracks volatility over a given time frame. It will move up or down depending on whether the asset's price movements are becoming more or less erratic -- a high ATR value represents high volatility, and a low value shows low volatility.

    The higher the ATR value, the wider the stop should be because a tight stop on a volatile market could get stopped out too early. Meanwhile, setting a stop too wide on a less volatile market could mean you're taking on more risk than necessary.

    Some traders even use the indicator can be used to determine the exact price level to attach a stop loss at. To do this, you'd multiply the ATR value by a figure of your choosing -- usually 0.5, 1, 2 or 3. This final number would be the point at which you'd set your stop loss.

    Longer-term investors would choose the higher end, multiply by 3, to get a value further away from the current market price. While short-term traders would stick to smaller multipliers, in order to have a smaller time period within which to take profit.

Trading exit strategy summed up
-------------------------------

-   An exit strategy ensures you stick to the decisions you've outlined in your trading plan and can mitigate the risk of emotional trading
-   Exit strategies minimise your risks and give you a higher chance of locking in profits
-   You can exit a trade using orders, including stop losses and take profits
-   Your exit strategy will depend on your trading style, risk-reward ratio and risk tolerance
-   Popular exit strategies include using support and resistance levels, moving averages and the average true range indicator

Ready to start trading? [Open an account](https://www.ig.com/en/application-form) now or practise using an exit strategy in a [risk-free demo account](https://www.ig.com/en/demo-account).

Publication date : Monday 15 February 2021 10:29
