Trading Exit Strategies -- Best Take Profit Techniques
=====================================================

| Author       | Source       | 
| :-------------: |:-------------:|
|  [Adam Abbas](https://www.linkedin.com/in/adamrabbas) | [Jumpstart Trading](https://www.jumpstarttrading.com/trading-exit-strategies/) | 

---

![Trading Exit Strategies](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/tradingexitstrategies-1030x539.png)

Determining the appropriate exit strategies while trading is just as important as determining when to get into a trade.

Money management is one of the main reasons most traders fail.  Many traders will enter a trade without an exit strategy already in place which usually leads to premature profits and in most cases losses.

It's imperative as a trader you determine where you will exit a trade while you still have complete objectivity. The only time you have complete objectivity is prior to entering a trade. Once in a trade emotions enter and can lead a trader without a plan to erratic decisions and poor trading.

The following is a list of some basic trading exit strategies that can greatly improve the profits of your trading strategy.

Trading Exit Strategies
-----------------------

### Key Resistance Levels

A great exit strategy is to piece out of a trade at key resistance levels as it moves in your favor. This strategy is especially useful in choppier markets when trades aren't haven't much follow through.

The following are a few key levels you can use:

-   Daily Pivot
-   Yesterday's High and Low
-   Overnight High and Low
-   30 Minute Opening Range High and Low
-   Intraday Swing Highs and Lows

You shouldn't get carried away with drawing too many support and resistance levels on your charts. Doing so can lead to hesitation and overthinking on trades. Keep it simple.

[![Key Resistance Level Exit Strategy](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Key-Resistance-Level-Exit-Strategy-1030x525.png)](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Key-Resistance-Level-Exit-Strategy.png)

On the above example you decide to go long Amazon (AMZN) on a bounce off the daily pivot at $762.25. The overnight high is too close of a target so you look to cover a portion of your position at the next resistance level which is yesterday's high. With no resistance levels close by after yesterday's high on this trade you could trail your stop on the remainder of the position below a moving average.

### Fixed Take Profit

When using a fixed take profit exit strategy you are simply looking to make the same amount of ticks/pips on every single trade you take. This is my least favorite trading exit strategy because it doesn't take into account or adjust for market volatility. However, this strategy still has it's place and used a lot by scalpers.

[![Fixed Take Profit](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Fixed-Take-Profit-1030x539.png)](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Fixed-Take-Profit.png)

As seen above,  you decide to go long Facebook (FB) on a break above yesterday's high at $117.60. You have a fixed take profit of 50 cents which is eventually hit at $117.90.

### Fixed & Run

I have been teaching and personally trading the fixed and run exit strategy for years. The theory behind the strategy is to get off half of your position early and move your stop loss to break even as fast as possible. The remaining half of the position you will let run for a large winner.

[![Fixed & Run Exit Strategy](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Fixed-Run-Exit-Strategy-1030x509.png)](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Fixed-Run-Exit-Strategy.png)

You decided to go long Twitter (TWTR) at $16.55 on the open as seen above. Your initial stop loss is below the swing low at $16.40. Twitter begins to rally and you take off half of your position at $16.65 and move your stop loss on the remainder to $16.45. At this point you have a risk free trade on and let the remainder of the position run. (Note: You could move your stop a little tighter after hitting first take profit in order to cover commissions if you were stopped out.)

You can use any of the other strategies discussed in this article to manage  remainder of your position.

This fixed and run exit strategy is one of the best for new traders struggling to hold on to winners or if you're in a lengthy drawdown.

As a new trader or someone who is struggling it's very difficult to hold on to winning trades. The second you see some profit you want to exit. This strategy makes it easier to hold on to winning trades.

### Fibonacci Extensions

Fibonacci extensions are awesome as they allow you to easily calculate your Reward to Risk ratios prior to entering a trade. They also are based on the most recent swing high or low so they are constantly adjusting for market volatility.

You use Fibonacci Extensions when you're looking for a completion of the CD Leg of an ABCD trading pattern.

The lines that form A t0 B and C t0 D are known as the legs (AB Leg & CD Leg) while the B to C line is called the Retracement.

![ABCD Pattern](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/ABCD-Pattern-1030x512.png)

The ABCD pattern shows up on in trading all the time. When using fibonacci extensions to manage your exits the AB leg and BC retracement will already have formed. You should be looking for the completion of the CD leg to exit at D.

The AB & CD legs will be equal in terms of length (price movement). They should also be close in the amount of time they take to complete.

![Fibonacci Extension Exit Strategy](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Fibonacci-Extension-Exit-Strategy-1-1030x526.png)

For example, let's assume you decide to go long Facebook (FB) at $119.40 when it broke back above the prior day's low. As seen on the chart above the AB Leg and BC Retracement have already formed.

To determine where the CD leg should complete you would select your Fibonacci Extension tool on your trading platform and click on the swing low (A) and move your cursor to the swing high (B) and then back down to the retracement of (C).

Now the fib extensions will be displayed on your chart. You have several options for determining where you will take profit. On the example above you can see the 50%, 61.8%, 78.6%, and 100% extensions as potential exits. Backtest with your strategy what extensions work best.

An alternative option is to use the extension levels as your support and resistance areas and implement the S&R Step Strategy discussed next.

### S&R Step

The Support and Resistance Step strategy is great in trending markets. You move your stop loss behind the break of a resistance level (now a support level) after price breaks and closes above the next resistance level.

The following are some examples of what you can use to determine your support and resistance levels.

-   Fibonacci Extensions
-   Daily Pivot
-   Yesterday's High and Low
-   Overnight High and Low
-   30 Minute Opening Range High and Low
-   Intraday Swing Highs and Lows

![Fib Extension Step Method](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Fib-Extension-Step-Method-1030x520.png)

Let's look at the trade you took earlier on Facebook (FB). You entered at $119.40 as seen above. As price rallies and closes above the 50% extension level you move your stop loss below the 38.2% extension level. Price continues to rally breaking and closing above the 61.8% extension level. You would continue to do this as each new extension level (or any other support level you want to use) is broke until you reach the completion of the CD Leg (100% extension) or until you're stopped out.

### Swing Highs & Lows

Swing highs are the peaks reached on a security when the high of a price is greater than surrounding price action. A new swing high is made when price breaks down to new lows.

Swing lows are the troughs reached on a security when the low of a price is greater than surround price action. A new swing low is created when price breaks out to new highs.

Below are some examples of swing highs and lows.

[![Swing Highs & Lows](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Swing-Highs-Lows-1030x526.png)](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Swing-Highs-Lows.png)

When trading using the Swing exit strategy you move your stop loss below ever new swing low when long and above every new swing high when short.

![Swing High/Low Trailing Stop](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Swing-HighLow-Trailing-Stop-1030x525.png)

On the above trade you would have placed your initial stop above Swing High #1 when you entered. As each new swing high forms you continue to move your stop until it's hit. You would have been stopped out on this trade at $116.73.

### Fixed Trailing Stop

A fixed trailing stop will automatically adjust your stop loss by an amount that you define as a trade moves in your favor. Your position must move a certain amount of ticks/pips/points defined by you in order for the stop to move.

For example, assume you short Facebook (FB) at 117.30 as seen below with an initial stop of 20 cents and a fixed step of 10 cents.

[![Fixed Trailing Stop](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Fixed-Trailing-Stop-1030x514.png)](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Fixed-Trailing-Stop.png)

As price begins to decline and hits $117.20 (10 cent decline) your stop will automatically adjust down 10 cents to $117.40. You're stop will continue to adjust 10 cents for ever 10 cents Facebook continues to decline until you are stopped out.

### Dynamic Trailing Stop

A Dynamic Trailing Stop also automatically adjusts your stop as price moves in your favor. However, with a dynamic trailing stop your stop loss will move every single time the market moves 1 tick/pip/point in your favor.

For example, once again you decide to short Facebook (FB) at $117.30 with an initial stop at $117.50.

[![Dynamic Trailing Stop](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Dynamic-Trailing-Stop-1030x522.png)](https://www.jumpstarttrading.com/wp-content/uploads/2016/12/Dynamic-Trailing-Stop.png)

As seen on the chart above, your stop loss begins to adjust down by 1 cent for every cent Facebook moves in your favor until your stop is hit.

Trading Exit Strategy Tips
--------------------------

-   You must determine your exit strategy prior to entering a trade while you still have complete objectivity.
-   No matter what exit strategy you use you need to allow a trade enough room to develop when determining your stop loss.
-   If you are getting stopped out on a lot of trades that ended up being winners try using the most recent swing size as your stop loss.
-   S&R Step, Fibonacci Extensions, and Swing Highs and Lows are great methods to use in trending markets.
-   In choppier markets using key resistance levels to piece out of trades is very effective.
-   Different exit strategies will work better in different markets. You need to backtest all of them before ever trading live!
-   If you're a new trader or in an extended drawdown try the Fixed and Run Method to hold on to your winners longer.

There's a look at 8 different trading exit strategies you can implement with your current trading strategy. Once again, make sure you always backtest anything new before going live! Hope you enjoyed this post. Try a few of these strategies out and let us know how it goes!
