Key Points About Regulation SHO
===============================

| Author       | Source       | 
| :-------------: |:-------------:|
|  [SEC](https://www.sec.gov/about.shtml) | [sec.gov](https://www.sec.gov/investor/pubs/regsho.htm) | 

---

I. Short Sales
--------------

### A. What is a short sale?

A short sale is generally the sale of a stock you do not own (or that you will borrow for delivery).[[1]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn1) Short sellers believe the price of the stock will fall, or are seeking to hedge against potential price volatility in securities that they own.

If the price of the stock drops, short sellers buy the stock at the lower price and make a profit. If the price of the stock rises, short sellers will incur a loss. Short selling is used for many purposes, including to profit from an expected downward price movement, to provide liquidity in response to unanticipated buyer demand, or to hedge the risk of a long position in the same security or a related security.

### B. Example of a short sale.

For example, an investor believes that there will be a decline in the stock price of Company A. Company A is trading at $60 a share, so the investor borrows shares of Company A stock at $60 a share and immediately sells them in a short sale. Later, Company A's stock price declines to $40 a share, and the investor buys shares back on the open market to replace the borrowed shares. Since the price is lower, the investor profits on the difference -- in this case $20 a share (minus transaction costs such as commissions and fees). However, if the price goes up from the original price, the investor loses money. Unlike a traditional long position --- when risk is limited to the amount invested --- shorting a stock leaves an investor open to the possibility of unlimited losses, since a stock can theoretically keep rising indefinitely.

### C. How does short selling work?

Typically, when you sell short, your brokerage firm loans you the stock. The stock you borrow comes from either the firm's own inventory, the margin account of other brokerage firm clients, or another lender. As with buying stock on margin,[[2]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn2) your brokerage firm will charge you interest on the loan, and you are subject to the margin rules. If the stock you borrow pays a dividend, you must pay the dividend to the person or firm making the loan.

### D. Are short sales legal?

Although the vast majority of short sales are legal, abusive short sale practices are illegal. For example, it is prohibited for any person to engage in a series of transactions in order to create actual or apparent active trading in a security or to depress the price of a security for the purpose of inducing the purchase or sale of the security by others. Thus, short sales effected to manipulate the price of a stock are prohibited.

II. "Naked" Short Sales
-----------------------

In a "naked" short sale, the seller does not borrow or arrange to borrow the securities in time to make delivery to the buyer within the standard three-day settlement period.[[3]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn3) As a result, the seller fails to deliver securities to the buyer when delivery is due (known as a "failure to deliver" or "fail").

Failures to deliver may result from either a short or a long sale. There may be legitimate reasons for a failure to deliver. For example, human or mechanical errors or processing delays can result from transferring securities in physical certificate rather than book-entry form, thus causing a failure to deliver on a long sale within the normal three-day settlement period. A fail may also result from "naked" short selling. For example, market makers who sell short thinly traded, illiquid stock in response to customer demand may encounter difficulty in obtaining securities when the time for delivery arrives.

"Naked" short selling is not necessarily a violation of the federal securities laws or the Commission's rules. Indeed, in certain circumstances, "naked" short selling contributes to market liquidity. For example, broker-dealers that make a market in a security[[4]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn4) generally stand ready to buy and sell the security on a regular and continuous basis at a publicly quoted price, even when there are no other buyers or sellers. Thus, market makers must sell a security to a buyer even when there are temporary shortages of that security available in the market. This may occur, for example, if there is a sudden surge in buying interest in that security, or if few investors are selling the security at that time. Because it may take a market maker considerable time to purchase or arrange to borrow the security, a market maker engaged in bona fide market making, particularly in a fast-moving market, may need to sell the security short without having arranged to borrow shares. This is especially true for market makers in thinly traded, illiquid stocks as there may be few shares available to purchase or borrow at a given time.

III. Regulation SHO
-------------------

Compliance with Regulation SHO began on January 3, 2005. Regulation SHO was adopted to update short sale regulation in light of numerous market developments since short sale regulation was first adopted in 1938 and to address concerns regarding persistent failures to deliver and potentially abusive "naked" short selling.

Due to continued concerns about failures to deliver, and to promote market stability and preserve investor confidence, the Commission has amended Regulation SHO several times since 2005 to eliminate certain exceptions, strengthen certain requirements and reintroduce the price test restriction.[[5]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn5)

As initially adopted, Regulation SHO included two major exceptions to the close-out requirement: the "grandfather" provision and the "options market maker" exception. Due to continued concerns about failures to deliver, and the fact that the Commission continued to observe certain securities with failure to deliver positions that were not being closed out under then existing requirements, in 2007 the Commission eliminated the "grandfather" provision and in 2008 the Commission eliminated the "options market maker" exception.

In addition, the Commission adopted temporary Rule 204T in 2008 and final Rule 204 in 2009, which strengthened further the close-out requirements of Regulation SHO by applying close-out requirements to failures to deliver resulting from sales of all equity securities and reducing the time-frame within which failures to deliver must be closed out.

In 2010, the Commission adopted Rule 201 of Regulation SHO. Rule 201 restricts the price at which short sales may be effected when a stock has experienced significant downward price pressure. Rule 201 is designed to prevent short selling, including potentially manipulative or abusive short selling, from driving down further the price of a security that has already experienced a significant intra-day price decline, and to facilitate the ability of long sellers to sell first upon such a decline.

Regulation SHO's four general requirements are summarized below:

-   *Rule 200 -- Marking Requirements.* Rule 200 requires that orders you place with your broker-dealer must be marked "long," "short," or "short exempt."[[6]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn6)

-   *Rule 201 -- Short Sale Price Test Circuit Breaker*. Rule 201 generally requires trading centers to establish, maintain, and enforce written policies and procedures that are reasonably designed to prevent the execution or display of a short sale at an impermissible price when a stock has triggered a circuit breaker by experiencing a price decline of at least 10 percent in one day. Once the circuit breaker in Rule 201 has been triggered, the price test restriction will apply to short sale orders in that security for the remainder of the day and the following day, unless an exception applies.

-   *Rule 203(b)(1) and (2) -- **Locate Requirement*. Regulation SHO requires a broker-dealer to have reasonable grounds to believe that the security can be borrowed so that it can be delivered on the date delivery is due before effecting a short sale order in any equity security.[[7]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn7) This "locate" must be made and documented prior to effecting the short sale.

-   *Rule 204 -- Close-out Requirement*. Rule 204 requires brokers and dealers that are participants of a registered clearing agency[[8]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn8) to take action to close out failure to deliver positions. Closing out requires the broker or dealer to purchase or borrow securities of like kind and quantity. The participant must close out a failure to deliver for a short sale transaction by no later than the beginning of regular trading hours on the settlement day following the settlement date, referred to as T+4. If a participant has a failure to deliver that the participant can demonstrate on its books and records resulted from a long sale, or that is attributable to bona fide market making activities, the participant must close out the failure to deliver by no later than the beginning of regular trading hours on the third consecutive settlement day following the settlement date, referred to as T+6. If the position is not closed out, the broker or dealer and any broker or dealer for which it clears transactions (for example, an introducing broker)[[9]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn9) may not effect further short sales in that security without borrowing or entering into a bona fide agreement to borrow the security (known as the "pre-borrowing" requirement) until the broker or dealer purchases shares to close out the position and the purchase clears and settles. In addition, Rule 203(b)(3) of Regulation SHO requires that participants of a registered clearing agency must immediately purchase shares to close out failures to deliver in securities with large and persistent failures to deliver, referred to as "threshold securities," if the failures to deliver persist for 13 consecutive settlement days.[[10]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn10) Threshold securities are equity securities[[11]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn11) that have an aggregate fail to deliver position for five consecutive settlement days at a registered clearing agency (e.g., National Securities Clearing Corporation (NSCC)); totaling 10,000 shares or more; and equal to at least 0.5% of the issuer's total shares outstanding. As provided in Rule 203 of Regulation SHO, threshold securities are included on a list disseminated by a self-regulatory organization ("SRO"). Although as a result of compliance with Rule 204, generally a participant's fail to deliver positions will not remain for 13 consecutive settlement days, if, for whatever reason, a participant of a registered clearing agency has a fail to deliver position at a registered clearing agency in a threshold security for 13 consecutive settlement days, the requirement to close-out such position under Rule 203(b)(3) remains in effect.

IV. Answers to Frequently-Asked Questions from Investors
--------------------------------------------------------

### 1\. Is all "naked" short selling abusive or illegal?

When considering "naked" short selling, it is important to know which activity is the focus of discussion.

-   *Selling stock short without having located stock for delivery at settlement*. This activity would violate Regulation SHO, except for short sales by market makers engaged in bona fide market making. Market makers engaged in bona fide market making do not have to locate stock before selling short, because they need to be able to provide liquidity. However, market makers are not excepted from Regulation SHO's close-out and pre-borrow requirements.

-   *Selling stock short and failing to deliver shares at the time of settlement*. Rule 204 requires firms that clear and settle trades to deliver securities to a registered clearing agency for clearance and settlement on a long or short sale in any equity security by the settlement date or to take action to close out failures to deliver by borrowing or purchasing securities of like kind and quantity by no later than the beginning of regular trading hours on T+4 for short sale fails or T+6 for long sale fails and fails attributable to bona fide market making. If a firm that clears and settles trades has a failure to deliver that is not closed out by the beginning of regular trading hours on T+4 or T+6, as applicable, the firm has violated Rule 204 and the firm, and any broker-dealer from which it receives trades for clearance and settlement, is subject to the pre-borrow requirement for that security.

-   *Selling stock short without having located stock for delivery at settlement and failing to deliver shares at the time of settlement*. This activity may violate Regulation SHO's locate and close-out requirements, as explained above. In addition, in fall 2008 the Commission adopted Rule 10b-21, referred to as the "naked" short selling antifraud rule. Those who deceive about their intention or ability to deliver securities in time for settlement are committing fraud, in violation of Rule 10b-21, when they fail to deliver securities by the settlement date.

-   *Selling stock short and failing to deliver shares at the time of settlement with the purpose of driving down the *security's* price*. This manipulative activity, in general, would violate various securities laws, including Rule 10b-5 under the Exchange Act.

### 2\. Is "naked" short selling the reason my stock has lost value?

Investors should always use caution before investing in high-risk, speculative stocks, especially with regard to their retirement portfolios, because all stocks may decline in value. There are many reasons why a stock may decline in value. The value of a stock is determined by the basic relationship between supply and demand. If many people want a stock (demand is high), then the price will rise. If a few people want a stock (demand is low), then the price will fall. The main factor determining the demand for a stock is the quality of the company itself. If the company is fundamentally strong, that is, if it is generating positive income, its stock is less likely to lose value.

Speculative stocks, such as microcap stocks, often have a high probability of declining in value and a low probability of experiencing above average gains.[[12]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn12) For example, investors should take extra care to thoroughly research any company not listed for trading on a national securities exchange, including companies which are closely held, extremely small or thinly traded.[[13]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn13) Such companies may not meet the minimum listing requirements for trading on a national securities exchange, such as the New York Stock Exchange or the Nasdaq Stock Market. Many of these companies do not file periodic reports or audited financial statements with the SEC, making it very difficult for investors to find reliable, unbiased information about those companies.

There also may be instances where a company insider or paid promoter provides false and misleading excuses for why a company's stock price has recently decreased. For instance, these individuals may claim that the price decrease is a temporary condition resulting from the activities of "naked" short sellers. The insiders or promoters may hope to use this misinformation to move the price back up so they can dump their own stock at higher prices. Often, the price decrease is a result of the company's poor financial situation rather than the reasons provided by the insiders or promoters.

"Naked" short selling, however, can have negative effects on the market. Fraudsters may use "naked" short selling as a tool to manipulate the market. Market manipulation is illegal.[[14]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn14) The SEC has toughened its rules including through the adoption of Rule 10b-21 in 2008, referred to as the "naked" short selling antifraud rule, and is vigilant about taking actions against alleged wrongdoers.[[15]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn15)

Failures to deliver that persist for an extended period of time may result in a significantly large unfulfilled delivery obligation at the clearing agency where trades are settled. Regulation SHO is intended to reduce the number of potential failures to deliver, and limit the time in which a broker can permit a failure to deliver to persist. For instance, as explained above, Regulation SHO generally requires firms that clear and settle trades to close out a failure to deliver resulting from a short sale by the beginning of regular trading hours on T+4.

### 3\. Do all failures to deliver reflect improper activity? After adoption of Rule 204, why are there still failures to deliver?

A failure to deliver occurs when a broker-dealer fails to deliver securities to the party on the other side of the transaction on the settlement date. There are many justifiable reasons why broker-dealers do not or cannot deliver securities on the settlement date. A broker-dealer may experience a problem that is either unanticipated or is out of its control, such as (1) delays in customers delivering their shares to a broker-dealer, (2) the inability to obtain borrowed shares in time for settlement, (3) issues related to the physical transfer of securities, or (4) the failure of a broker-dealer to receive shares it had purchased to fulfill its delivery obligations. Failures to deliver can result from both long and short sales.

Regulation SHO was designed to target potentially problematic failures to deliver. Prevention of fails is the goal of the locate requirement. Regulation SHO requires broker-dealers to identify a source of borrowable stock before executing a short sale in any equity security with the goal of reducing the number of situations where stock is unavailable for settlement. But, because the locate is usually done three days before settlement, the stock may not be available from the source at the time of settlement, possibly resulting in a fail.

Regulation SHO also requires firms that clear and settle trades to take action to close out failures to deliver by borrowing or purchasing securities of like kind and quantity. For short sale transactions, failures to deliver must be closed out by no later than the beginning of regular trading hours on the settlement day following the settlement date, referred to as T+4. For long sale transactions or bona fide market making activities, failures to deliver must be closed out by no later than the beginning of regular trading hours on the third settlement day following the settlement date, referred to as T+6.

Rule 204 provides an extended period of time to close out certain failures to deliver. Specifically, if a failure to deliver position results from the sale of a security that a person is deemed to own and that such person intends to deliver as soon as all restrictions on delivery have been removed, the firm has up to 35 calendar days following the trade date to close out the failure to deliver position by purchasing securities of like kind and quantity. Such additional time is warranted and does not undermine the goal of reducing failures to deliver because these are sales of owned securities that cannot be delivered by the settlement date due solely to processing delays outside the seller's or broker-dealer's control. Moreover, delivery is required to be made on such sales as soon as all restrictions on delivery have been removed and situations where a person is deemed to own a security are limited to those specified in Rule 200 of Regulation SHO. A common example of a deemed to own security that cannot be delivered by the settlement date is a security subject to the resale restrictions of Rule 144 under the Securities Act of 1933.

### 4\. What is meant by T+3?

Generally, investors must complete or settle their security transactions within three business days. This settlement cycle is known as "T+3," shorthand for "trade date plus three days."

T+3 means that when you buy a security, your payment must be received by your brokerage firm no later than three business days after the trade is executed. When you sell a security, you must deliver your securities, in certificated or electronic form, to your brokerage firm no later than three business days after the sale.

The three-day settlement date applies to most security transactions, including stocks, bonds, municipal securities, mutual funds traded through a brokerage firm, and limited partnerships that trade on an exchange. Government securities and stock options settle on the next business day following the trade.[[16]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn16)

Delivery on sales should be made by the settlement date. Under Rule 204, firms that clear and settle trades must deliver securities to a registered clearing agency for clearance and settlement on a long or short sale in any equity security by the settlement date or must take immediate action to close out failures to deliver by no later than the beginning of regular trading hours on T+4 (for short sales) or T+6 (for long sales and fails attributable to bona fide market making).

### 5\. After adoption of Rule 204, why are there still threshold securities and why is there still a threshold securities close-out requirement?

Even after adoption of Rule 204, failures to deliver may occur in certain circumstances. The appearance of a security on a threshold list does not necessarily mean that there has been abusive "naked" short selling or any impermissible trading in the stock. Delivery failures can be caused by both long and short sales. In addition, notwithstanding actions by broker-dealers to close out delivery failures, certain securities may remain on an SRO's[[17]](https://www.sec.gov/investor/pubs/regsho.htm#_ftn17) threshold securities list for a variety of legitimate reasons, such as:

-   Despite proper action to close out fails, new delivery failures from long or short sales, at the same or other broker-dealers, result in the security staying on the threshold list;
-   One or more broker-dealers may have temporary but legitimate problems in obtaining the stock they borrowed in time for delivery;
-   Long sellers may have difficulty in producing stock in good deliverable form to their broker-dealer.

Rule 203(b)(3) applies to fails to deliver in threshold securities if the participant's fails to deliver persist for 13 consecutive settlement days. Although as a result of compliance with Rule 204, generally a participant's fail to deliver positions will not remain for 13 consecutive settlement days, if, for whatever reason, a participant of a registered clearing agency has a fail to deliver position at a registered clearing agency in a threshold security for 13 consecutive settlement days, the requirement to close-out such position under Rule 203(b)(3) remains in effect.

### 6\. Do the issuers of threshold securities have "problems?"

Inclusion on the threshold list simply indicates that the aggregate failures to deliver in an issuer's equity securities have reached the level required to become a "threshold security" as defined in Regulation SHO. Inclusion on the list should not be interpreted as connoting anything negative about the particular issuer.

### 7\. Will close-out purchases required by Regulation SHO drive up a security's price?

Close-out purchases of stock will not necessarily drive up prices of such stocks. One of the primary purposes of Regulation SHO is to clean up open fail positions, but not to cause short squeezes. The term "short squeeze" refers to the pressure on short sellers to cover their positions as a result of sharp price increases or difficulty in borrowing the security the sellers are short. The rush by short sellers to cover produces additional upward pressure on the price of the stock, which then can cause an even greater squeeze. Although some short squeezes may occur naturally in the market, a scheme to manipulate the price or availability of stock in order to cause a short squeeze is illegal.

### 8\. Where can I obtain information on short sales?

To increase the transparency surrounding short sale transactions, several SROs are providing on their websites daily aggregate short selling volume information for individual equity securities. The SROs are also providing website disclosure on a one-month delayed basis of information regarding individual short sale transactions in all exchange-listed equity securities. Hyperlinks to short sale data provided by specific SROs are provided at the following website: <http://www.sec.gov/answers/shortsalevolume.htm>.

The SROs also publish monthly statistics on short interest in securities that trade on their markets. Short interest is the aggregate number of open short sale positions. Short interest does not address the number of failures to deliver that may have occurred or may occur in connection with these short sales.

Short interest for NYSE stocks can be found at: <http://www.nyxdata.com/nysedata/default.aspx?tabID=748>.

Short interest for Nasdaq stocks can be found at: <http://www.nasdaqtrader.com/Trader.aspx?id=ShortInterest>.

Short interest for over-the-counter equity securities can be found at: http://otce.finra.org/ESI.

There also are many commercial websites and some newspapers that offer this information. If you enter the words "short interest" into most Internet search engines, you'll quickly find websites that can provide this information.

### 9\. Where can I obtain fails information?

### The Commission publishes on its website failures to deliver data for all equity securities, regardless of the fails level, twice per month. For current failures to deliver information, see <http://www.sec.gov/foia/docs/failsdata.htm>.

**10\. Where can I find threshold lists?**

Threshold securities are included on a list disseminated by an SRO. If a threshold security is listed on more than one market system, the SROs have agreed that the security will appear only on the threshold list of the SRO that maintains the primary listing. FINRA publishes a list of OTC threshold securities. You can obtain SRO threshold lists at the following websites:

The Nasdaq Stock Market LLC\
<http://www.nasdaqtrader.com/Trader.aspx?id=RegSHOThreshold>

New York Stock Exchange LLC, NYSE MKT LLC and NYSE Arca, Inc.\
<https://www.nyse.com/regulation/threshold-securities>

Chicago Stock Exchange, Inc. (CHX)\
<http://www.chx.com/trading-information/threshold-securities/>

BATS Exchange, Inc.\
<http://batstrading.com/market_data/reg_sho_threshold_list/>

FINRA\
<http://otce.finra.org/RegSHO>

Other national securities exchanges that are not the primary listing exchange for any securities at this time are currently not publishing threshold securities lists.

Currently, threshold lists include the name and ticker symbol of securities that meet the threshold level on a particular settlement date. Some investors have requested that the SROs provide more detailed information for each threshold security, including the name of the broker-dealer firm responsible for the fails and the names of the customers of responsible brokers and dealers responsible for the short sales. The fails statistics of individual firms and customers is proprietary information and may reflect firms' trading strategies.

### 11\. I read on an internet chat room or website that a specific security has a large number of fails; are these sources reliable?

Investors can and should verify the number of failures to deliver in a specific security by checking publicly available data on failures to deliver. The Commission publishes on its website failures to deliver data for all equity securities, regardless of the fails level, twice per month. For current failures to deliver information, see <http://www.sec.gov/foia/docs/failsdata.htm>.

Investors should always be cautious that issuers, promoters, or shareholders may be seeking to stimulate buying interest by making false, misleading or unfounded statements in internet chat rooms or other such forums about alleged large "naked" short positions in some smaller issuers. Some individuals may encourage other investors to buy these issuers' securities by claiming that there will be an imminent short squeeze, in which the alleged "naked" short sellers will be forced to cover open short positions at increasing prices. These claims in fact may be false.

The Commission's Office of Investor Education and Assistance has made available publications on the Commission's website (<http://www.sec.gov/investor.shtml>) that provide helpful guidance on the securities markets and sales and trading practices, including short selling. The Office of Investor Education and Advocacy has also established a website dedicated to retail investors, <http://investor.gov/>. Investors and prospective investors should be cautious of rumors on chat rooms where the intent of nameless and faceless computer users is in doubt.

### 12\. Where can I find information on specific issuers or securities?

To find information on issuers and securities, see <http://www.sec.gov/investor/pubs/easyaccess.htm>. Information on researching public companies is also available at <http://investor.gov/researching-managing-investments/researching-investments>.

### 13\. Does NSCC's stock borrow program create "counterfeit shares?"

NSCC's stock borrow program, as approved by the Commission, permits NSCC to borrow securities from its participants for the purpose of completing settlements only if participants have made those securities available to NSCC for this purpose and those securities are on deposit in the participant's account at DTC.

### 14\. Where can I submit information on potential violations of the federal securities laws?

If you have specific enforcement-related information, please see <http://www.sec.gov/complaint/tipscomplaint.shtml> for information on how to submit a complaint. You may also call 1-800-SEC-0330.

### 15\. Where can I find information on investigations or enforcement actions pending against specific issuers or regarding specific securities?

As a policy, the SEC will neither confirm nor deny the existence of an investigation unless, and until, it becomes a matter of public record as the result of a court action or administrative proceeding. SEC investigations are conducted on a non-public and confidential basis to help assure the integrity of the investigative process. See <http://www.sec.gov/complaint/tipscomplaint.shtml> for more information on how the Commission handles complaints.

To view enforcement actions that the Commission has taken, see <http://www.sec.gov/litigation/litreleases.shtml>.

V. Reporting Alleged Abusive "Naked" Short Selling Activity
-----------------------------------------------------------

The markets and the SROs are primarily responsible for the surveillance and enforcement of trading activity pursuant to their rules. The SEC, however, independently or in conjunction with the SROs and other regulatory authorities, actively investigates and prosecutes violations of the federal securities laws.

The SEC takes information alleging violations of the federal securities laws very seriously. If you have specific enforcement-related information, please submit the information at <http://www.sec.gov/complaint/tipscomplaint.shtml>. Please note, however, the SEC will neither confirm nor deny the existence of an investigation unless, and until, it becomes a matter of public record as the result of a court action or administrative proceeding. As you may also be aware, SEC investigations are conducted on a non-public and confidential basis to help assure the integrity of the investigative process. See <http://www.sec.gov/complaint/info_tipscomplaint.shtml> for more information on how the Commission handles complaints.

VI. Regulation SHO -- Releases and Other Guidance
------------------------------------------------

The final adopting release for Regulation SHO and other key documents relating to short sale regulation, such as the "Frequently Asked Questions Regarding Regulation SHO" published by the Staff of the Division of Trading and Markets, are available on the Commission's website at: <http://www.sec.gov/spotlight/shortsales.htm>.

VII. Who Do I Contact If I Have Questions about Regulation SHO?
---------------------------------------------------------------

Individual investors who have comments or information should feel free to contact the SEC's Office of Investor Education and Assistance at 1-800-SEC-0330 or (202) 942-7040. Investors can also file complaints at <http://www.sec.gov/complaint/tipscomplaint.shtml>.

* * * * *

[[1]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref1) For more information on short sales, see <http://www.sec.gov/answers/shortsale.htm>.

[[2]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref2) For information regarding margin, please see <http://www.sec.gov/answers/margin.htm>.

[[3]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref3) For more information on the three-day settlement period, also known as "T+3," see <http://www.sec.gov/answers/tplus3.htm> and <http://www.sec.gov/investor/pubs/tplus3.htm>.

[[4]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref4) For more information about market making, see <http://www.sec.gov/answers/mktmaker.htm> and <http://www.sec.gov/answers/specialist.htm>.

[[5]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref5) See Exchange Act Release No. 55970 (Jun. 28, 2007), 72 FR 36348 (Jul. 3, 2007); Exchange Act Release No. 56212 (Aug. 7, 2007), 72 FR 45544 (Aug. 14, 2007); Exchange Act Release No. 58775 (Oct. 14, 2008), 73 FR 61690 (Oct. 17, 2008); Exchange Act Release No. 60388 (July 27, 2009), 74 FR 38266 (July 31, 2009); Exchange Act Release No. 61595 (Feb. 26, 2010), 75 FR 11232 (Mar. 10, 2010).

[[6]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref6) Under the rule, an order can be marked "long" when the seller owns the security being sold and the security either is in the physical possession or control of the broker-dealer, or it is reasonably expected that the security will be in the physical possession or control of the broker or dealer no later than settlement. However, if a person does not own the security, or owns the security sold but it is not reasonably expected that the security will be in the possession or control of the broker-dealer prior to settlement, the sale should be marked "short." The sale could be marked "short exempt" if the seller is entitled to rely on an exception from the short sale price test circuit breaker.

[[7]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref7) Broker-dealers engaged in bona fide market making are excepted from having to borrow or arrange to borrow shares due to their potential need to facilitate customer orders in fast-moving markets without possible delays associated with complying with Regulation SHO. For instance, as explained above, they may be required by their market making obligations to sell short in situations where it may be difficult to quickly locate and borrow securities. However, this exception is limited. For example, bona fide market making does not include activity that is related to speculative selling strategies or investment purposes of the broker-dealer or that is disproportionate to the usual market making patterns or practices of the broker-dealer in that security. Further, bona fide market making does not include transactions whereby a market maker enters into an arrangement with another broker-dealer or customer in an attempt to use the market maker's exception for the purpose of avoiding compliance with the locate requirement in Regulation SHO by the other broker-dealer or customer.

[[8]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref8) Clearing Agencies are self-regulatory organizations that are required to register with the Commission. See <http://www.sec.gov/divisions/marketreg/mrclearing.shtml> and [www.dtcc.com](http://www.sec.gov/cgi-bin/goodbye.cgi?www.dtcc.com/) for more information about the clearance and settlement process and DTCC. A participant of a clearing agency means any person or firm, such as a broker-dealer, that uses a clearing agency to clear and settle securities transactions or to transfer, pledge, lend, or hypothecate securities. It does not include a person or firm whose only use of a clearing agency is (a) through another person or firm that is a participant or (b) as a pledgee of securities. Section 3(a)(24) of the Exchange Act, 15 U.S.C. 78c(a)(24).

[[9]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref9) Introducing brokers are typically brokers that perform all the functions of a broker except for the ability to accept money, securities, or property from a customer. They are usually not participants of registered clearing agencies and do not perform clearance and settlement functions. See Footnote 9 for more information about participants of a clearing agency.

[[10]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref10) Settlement day means any business day on which deliveries of securities and payments of money may be made through the facilities of a registered clearing agency.

[[11]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref11) Under Regulation SHO, threshold securities only include issuers registered or required to file reports with the Commission ("reporting companies"). FINRA Rule 4320 applies threshold close-out requirements to non-reporting securities.

[[12]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref12) See <http://www.sec.gov/investor/pubs/microcapstock.htm> for more information.

[[13]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref13) Many of these stocks are also considered "penny stocks." See <http://www.sec.gov/answers/penny.htm>. Because penny stocks are generally risky investments, before a broker-dealer can sell a penny stock, SEC rules require the firm to first approve the customer for the transaction and receive from the customer a written agreement to the transaction. The firm must furnish the customer a document describing the risks of investing in penny stocks. The broker-dealer must tell the customer the current market quotation, if any, for the penny stock and the compensation the firm and its broker will receive for the trade. Finally, the firm must send monthly account statements showing the market value of each penny stock held in the customer's account.

[[14]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref14) The Commission brought an enforcement action against certain parties, alleging manipulative "naked" short selling, in a scheme sometimes termed as a "death spiral." See Rhino Advisors, Inc. and Thomas Badian, Lit. Rel. No. 18003 (February 27, 2003) at <http://www.sec.gov/litigation/litreleases/lr18003.htm>.

[[15]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref15) *See* *In the Matter of Gonul Colak and Milen K. Kostov*, Exchange Act Release No. 71461 (Jan. 31, 2014) (settled administrative proceeding), available at <http://www.sec.gov/litigation/admin/2014/33-9522.pdf>; *In the Matter of optionsXpress, et al.*, Admin. Proc. File No. 3-14848 (June 7, 2013), available at <http://www.sec.gov/alj/aljdec/2013/id490bpm.pdf>; *In the Matter of Jeffrey Wolfson, et al*., Exchange Act Release No. 67450 (July 17, 2012) (settled administrative proceeding) available at <http://www.sec.gov/litigation/admin/2012/34-67450.pdf>; *In the Matter of Jeffrey Wolfson, et al.*, Exchange Act Rel. No. 67451 (July 17, 2012) (settled administrative proceeding) available at <http://www.sec.gov/litigation/admin/2012/34-67451.pdf>; *In the Matter of Gary S. Bell*, Exchange Act Release No. 65941 (Dec. 13, 2011) (settled administrative proceeding), available at <http://sec.gov/litigation/admin/2011/34-65941.pdf>; *In the Matter of Rhino Trading, LLC, Fat Squirrel Trading Group, LLC, Damon Rein, and Steven Peter*, Exchange Act Release No. 60941 (Nov. 4, 2009) (settled administrative proceeding), available at <http://www.sec.gov/litigation/admin/2009/34-60941.pdf>; *In the Matter of Hazan Capital Management, LLC and Steven M. Hazan*, Exchange Act Release No. 60441 (Aug. 5, 2009) (settled administrative proceeding) available at <http://www.sec.gov/litigation/admin/2009/34-60441.pdf>*; In the Matter of TJM Proprietary Trading, LLC, et al.*, Exchange Act Release No. 60440 (Aug. 5, 2009) (settled administrative proceeding) available at <http://www.sec.gov/litigation/admin/2009/34-60440.pdf>.

[[16]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref16) For more information about T+3, see <http://www.sec.gov/investor/pubs/tplus3.htm>.

[[17]](https://www.sec.gov/investor/pubs/regsho.htm#_ftnref17) A self-regulatory organization is a membership-based organization that creates and enforces rules for its members based on the federal securities laws. SROs, which are overseen by the SEC, are the front line in regulating broker-dealers. See <http://investor.gov/introduction-markets/how-markets-work/market-participants#.VFuPujZOncs> for more information.

*http://www.sec.gov/investor/pubs/regsho.htm*

![The Office of Investor Education and Advocacy has provided this information as a service to investors.  It is neither a legal interpretation nor a statement of SEC policy.  If you have questions concerning the meaning or application of a particular law or rule, please consult with an attorney who specializes in securities law.](https://www.sec.gov/images/oieadisclaimer2009.gif)

* * * * *
###### Modified: 4/8/2015

---


> **:information_source: Key Highlights and Takeaways** by [u/Meticulous-](https://www.reddit.com/user/Meticulous-)
> 
> **What is short selling?**
> 
> [Short selling](https://www.investopedia.com/terms/s/shortselling.asp) is selling a stock that **you do not own**.
> 
> **Is short selling illegal?**
> 
> Although the vast majority of short sales are legal, abusive short sale practices are illegal.
> 
> **What is naked short selling?**
> 
> [Naked shorting](https://www.investopedia.com/terms/n/nakedshorting.asp#:~:text=Naked%20shorting%20is%20the%20illegal,before%20they%20sell%20it%20short.) is an illegal practice of short selling shares that **do not exist**. This causes a failure to deliver (FTD).
> 
> **What is a Failure to Deliver (FTD)?**
> 
> A FTD results from either a short or long sale. FTDs can occur due to 
> 1. Human or mechanical errors such as processing delays
> 2. Buyers not having enough cash
> 3. Sellers not having the securities
> 
> **What is the Regulation SHO?**
> 
> [Regulation SHO](https://www.investopedia.com/terms/r/regsho.asp) was a rule created by the SEC in 2005 to govern short selling.
> 
> In 2010, the Regulation SHO was amended to stop short selling on a security when prices have decreased by 10% or more during the trading day.

