Testimony Before the House Committee on Financial Services
==========================================================

| Author       | Source       | 
| :-------------: |:-------------:|
|  [Gary Gensler](https://www.sec.gov/biography/gary-gensler) | [sec.gov](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery) | 

---

![Chair Gary Gensler](https://www.sec.gov/files/styles/thumbnail/public/chair-gary-gensler_0.jpg?itok=aSy6ReUY)

Washington D.C.

May 6, 2021

Good afternoon, Chairwoman Waters, Ranking Member McHenry, and members of the Committee. I'm honored to appear before you today for the first time as Chair of the Securities and Exchange Commission. Thank you for inviting me to testify on the market volatility we witnessed in January. I'd like to note that my views are my own, and I am not speaking on behalf of my fellow Commissioners or the staff.

We've all come to hear the general story: a stock that went from $20 to $480 and back down to $40, all in a matter of weeks. It opened at $162 Wednesday of this week. GameStop, though, was just one of the many so-called meme stocks that exhibited significant price volatility, trading volume, and attention in the markets in January. As these events reached an apex in late January, a number of broker-dealers imposed trading restrictions on some of these stocks.

While entities such as GameStop, Melvin Capital, Reddit, and Robinhood have garnered a significant amount of attention, the policy issues raised by this winter's volatility go beyond those companies. Instead, I think these events are part of a larger story about the intersection of finance and technology.

These forces have had a symbiotic relationship since antiquity. One thing that I've come to believe is that technology can bring greater access to our capital markets.

Our central question is this: When new technologies come along and change the face of finance, how do we continue to achieve our core public policy goals and ensure that markets work for everyday investors?

As we work to protect investors, maintain fair, orderly, and efficient markets, and facilitate capital formation, I'd like to highlight seven factors that were at play in these volatile events:

-   Gamification and User Experience
-   Payment for Order Flow
-   Equity Market Structure
-   Short Selling and Market Transparency
-   Social Media
-   Market "Plumbing": Clearance and Settlement
-   System-Wide Risks

We expect to publish a staff report assessing the market events over the summer. While I cannot comment on ongoing examination and enforcement matters, SEC staff is vigorously reviewing these events for any violations. I also have directed staff to consider whether expanded enforcement mechanisms are necessary.

Gamification and User Experience
--------------------------------

Mobile apps have done a lot to expand access to capital markets, making it easy for investors to sign up, start trading, get wealth management advice, and learn about investing. These apps use a host of features that have come to be familiar in our increasingly online world --- features such as gamification, behavioral prompts, predictive analytics, and differential marketing.

There isn't a settled definition of gamification, but broadly, it refers to the use of game-like features --- such as points, rewards, leaderboards, bonuses, and competitions --- to increase customer engagement.

Beyond gamification, there are also behavioral prompts that encourage users to engage more with an app, much like push notifications we receive on breaking news stories. Other features, such as social trading or copy trading, allow customers to see what others are buying and selling and make trades influenced by that information.

Underpinning many of these features is predictive data analytics, which has allowed apps to analyze the success of individual gamification and behavioral prompts to increase activity. Based on such data analytics, users might see an ever-changing set of features that are differentially communicated to different customer segments.

These types of features are implemented across many different technologies, from streaming platforms to fitness trackers.

If we watch a movie that a streaming app recommends and don't like it, we might lose a couple of hours of our evening. If a fitness app nudges us to exercise, that's probably a good thing.

Following the wrong prompt on a trading app, however, could have a substantial effect on a saver's financial position. A big loss could have immediate implications for the app user's ability to afford their rent or pay other important bills. A small loss now could compound into a significant loss at retirement.

Many of these features encourage investors to trade more. Some academic studies suggest more active trading or even day trading results in lower returns for the average trader.

It's in this context that I've asked staff to prepare a request for public input for consideration on these issues. We need to ensure investors using apps with these types of features continue to be appropriately protected and consider how all of our rules apply in these situations, including Regulation Best Interest. In addition, many of our regulations were largely written before these recent technologies and communication practices became prevalent. I think we need to evaluate our rules, and we may find that we need to freshen up our rule set. If we don't address this now, the investing public --- those saving for their futures, retirements, and education --- may shoulder a burden later.

Payment for Order Flow
----------------------

Why might brokerage firms want to increase customer trading? Who benefits from it?

In the last few years, most retail broker-dealers have stopped charging fees for trades. Instead, some make money through other streams, including a process called payment for order flow. Robinhood publicly reported $331 million in payment for order flow revenues in the first quarter of this year, more than triple the amount it brought in during the first quarter of 2020.[[1]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftn1)

There are two kinds of payment for order flow I'd like to highlight: payments from wholesalers to brokers, and from exchanges to market makers and to brokers.

Here, I focus on payment from wholesalers to brokers. Here's how that process works: retail broker-dealers enter into agreements with wholesalers, which purchase their order flow. Unlike public exchanges that must offer fair access to their publicly displayed quotes, these wholesalers can decide whether to execute these orders directly or to pass them along to be executed by the exchanges or other trading venues.

In addition, the wholesalers get valuable information from this order flow that other market participants get with a delay, if at all. In many aspects of the economy, from social media to search engines, access to data is a growing competitive advantage. Our capital markets are no different.

Higher volumes of trades generate more payments for order flow. This brings to mind a number of questions: Do broker-dealers have inherent conflicts of interest? If so, are customers getting best execution in the context of that conflict? Are broker-dealers incentivized to encourage customers to trade more frequently than is in those customers' best interest? What are the policy implications with regard to the data aggregated by the purchasers of order flow?

These questions, while not new, were highlighted in the SEC's recently settled enforcement action against Robinhood.[[2]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftn2) As described in the Commission's order, certain principal trading firms seeking to attract Robinhood's order flow told them that there was a tradeoff between payment for order flow and price improvement for customers. Robinhood explicitly offered to accept less price improvement for its customers in exchange for receiving higher payment for order flow for itself. As a result, many Robinhood customers shouldered the costs of inferior executions; these costs might have exceeded any savings they might have thought they'd gotten from a zero commission.

Finally, it's interesting to note that neither the United Kingdom[[3]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftn3) nor Canada[[4]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftn4) permits broker-dealers to route retail orders to off-exchange market makers in return for payments.

Equity Market Structure
-----------------------

January's events bring new light to equity market structure. Today, our markets essentially have three different segments. While the public generally thinks of the markets as public exchanges like Nasdaq and New York Stock Exchange, those big public markets had about 53 percent of the volume in January, according to public data.[[5]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftn5) So where's the other 47 percent?

About 9 percent of January's volume was executed at alternative trading systems. These alternative trading systems, commonly known as dark pools, emerged following the 1998 Regulation ATS rules, taking advantage of then-new advances in the internet and communications technologies.

That leaves about 38 percent, the majority of which was executed by off-exchange wholesalers, a group that of firms that have been taking a growing share of trading volume. As publicly available data on reported trades show, just seven wholesalers made up the vast majority of this 38 percent. One firm, Citadel Securities, has publicly stated that it executes about 47 percent of all retail volume.[[6]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftn6) In January, two firms executed more volume than all but one exchange, Nasdaq.[[7]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftn7)

The high concentration of retail orders routed to a small number of wholesalers raises a number of questions about market structure. In essence, does this segmentation and related sector concentration best promote fair, orderly, and efficient markets?

History and economics tell us that when markets are concentrated, those firms with the greatest market share tend to have the ability to profit from that concentration. Market concentration can also lead to fragility, deter healthy competition, and limit innovation. I've asked staff to look closely at these issues to determine which policy approaches may be merited.

Short Selling and Market Transparency
-------------------------------------

At the center of January's market events was significant short selling of a number of the meme stocks. While FINRA and the exchanges currently publish or make available certain short sale data, Congress directed the SEC under the Dodd-Frank Act to publish rules on monthly aggregate short sale disclosures. In addition, Dodd-Frank provided authority to the SEC to increase transparency in the stock loan market. I've directed SEC staff to prepare recommendations for the Commission's consideration on these issues.

Additionally, I wanted to mention briefly the events in late March related to the failure of the family office Archegos Capital Management and the significant losses incurred by several global financial institutions that provided prime brokerage services to Archegos. At the core of that story was Archegos' use of total return swaps based on underlying stocks, and significant exposure that the prime brokers had to the family office. Under Dodd-Frank, Congress gave the SEC rulemaking authority to extend beneficial ownership reporting requirements to total return swaps and other security-based swaps. Among other things, I've asked staff to consider recommendations for the Commission about whether to include total return swaps and other security-based swaps under new disclosure requirements, and if so how.

Social Media
------------

This winter's events also highlighted the rapidly changing face of social media and its intersection with our capital markets. Online forums can serve as a real community, expanding access and participation. On Reddit, individuals gather in online communities to discuss a variety of topics anonymously, including investing; the subreddit r/wallstreetbets has about 10 million members.[[8]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftn8) A lot of people follow capital markets through various online communities --- not only on Reddit, but also on other social media platforms and within trading apps.

New communications channels have long brought opportunities and challenges for markets. Today's social media tools have far greater reach, scale, and anonymity than previous technologies. This raises a potential issue: the possibility that wrongdoers will attempt to use these powerful forums to hype certain stocks or manipulate markets.

To be clear, I'm not concerned about regular investors exercising their free speech online. I am more concerned about bad actors potentially taking advantage of influential platforms.

Furthermore, it's no longer just retail investors or even humans who are following these online conversations, but institutional investors and their algorithms. Developments in machine learning, data analytics, and natural language processing have allowed sophisticated investors to monitor various forms of public communication to see relationships between words and prices.

This practice, called sentiment analysis, has picked up steam in the last couple of years, and it has grown to include online communities. With that comes the risk that nefarious actors may try to send signals to manipulate the market. This is an area for which we will continue to deepen our understanding, resources, and capabilities.

Market "Plumbing": Clearance and Settlement
-------------------------------------------

In January, several broker-dealers decided to restrict customer access to trading in certain meme stocks. These decisions understandably drew a lot of questions from the investing public. Many investors lost access to the market at a critical time.

Clearing has been a crucial part of our capital markets since the 19th century. Clearinghouses are the buyer to every seller, and the seller to every buyer. They reduce risk and operational complexity in capital markets. Centralized clearing of standardized swaps and security-based swaps was mandated by the Dodd-Frank Act after the financial crisis.

When an investor enters into a trade on a Monday, the cash and the securities related to that trade settle on a Wednesday; that's called a settlement cycle of trade day plus two days ("T+2"). Clearinghouses have rules to cover the credit, market, and liquidity risk that is present during those two days. All members transacting with the clearinghouses need to post collateral, called margin, to cover potential losses. If the broker went bankrupt before the trade is settled, the clearinghouse would use such margin to back the deliveries and payments with the goal of not disrupting the broader financial system.

In January, the rapidly changing prices, high volatility, and significant trading volume of the meme stocks prompted larger-than-usual central clearing margin calls on broker-dealers. Some of those broker-dealers, such as Robinhood, scrambled to secure new funding to post the required margin. A number of brokers chose to restrict additional buying activity by their customers in a variety of the meme stocks.

These decisions call into question whether broker-dealers are adequately disclosing their policies and procedures around potential trading restrictions; whether margin requirements and other payment requirements are sufficient; and whether broker-dealers have appropriate tools to manage their liquidity and risk. I've asked staff to look at these issues carefully.

With regard to the settlement cycle, I'm reminded of an old saying in the markets: "Time equals risk." These events have prompted questions about whether we can lower risk by shortening the time of our settlement cycles.  

Interestingly, if one goes back to the 1920s, our capital markets had a one-day settlement cycle. This was prior to the establishment of the SEC, so it was a matter of convention rather than a regulatory requirement. Throughout the 20th century, the length of the settlement cycle ebbed and flowed; it was as long as five days. In 2017, the SEC adopted a rule to shorten the standard settlement cycle from three days (T+3) to two days (T+2). The Depository Trust & Clearing Corporation and other industry groups recently announced their intention to study these issues and collaborate on efforts to accelerate the transition to T+1.[[9]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftn9)

The longer it takes for a trade to settle, the more risk our markets assume. The good news is, though it will take a lot of work by many parties, we now have the technology to further shorten the settlement cycles, not only to the settlement cycle we had a century ago, but even to same-day settlement (T-0 or "T-evening").

I believe shortening the standard settlement cycle could reduce costs and risks in our markets. I've directed the SEC staff to put together a draft proposal for the Commission's review on this topic.

System-Wide Risks
-----------------

Whenever there are major market events, it's a good idea to consider what risks they might have placed on the entire financial system, even when the system holds. I'd like to highlight a few areas:

First, at least one firm didn't have sufficient liquidity to meet margin calls and had to fundraise within hours to meet $1 billion-plus obligations, and several brokers chose to shut down customer access to trading. While these liquidity challenges faced by brokers didn't cascade to the rest of the economy, they did, unfortunately, affect many investors' ability to trade.

Second, several hedge funds lost significant money during these events. Though it doesn't appear to have triggered broader market events, at least one fund had to raise funds rapidly to cover losses. Further, as was publicly reported with the Archegos situation, losses at individual firms can have wider impacts on the banking system.

Third, issues of concentration, whether among market makers or brokers at the clearinghouse, may increase potential system-wide risks, should any single incumbent with significant size or market share fail.

***

Thank you. I look forward to answering your questions.

* * * * *

[[1]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftnref1) *See *Wall Street Journal, "Robinhood's Biggest Business More Than Tripled Amid Trading Frenzy" (May 2, 2021), *available at* <https://www.wsj.com/articles/robinhoods-biggest-business-more-than-tripled-in-the-first-quarter-11619975534?mod=searchresults_pos1&page=1>.

[[2]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftnref2) *See *Securities Act Release No. 10906, "In the Matter of Robinhood Financial, LLC" (Dec. 17, 2020),* available at* <https://www.sec.gov/litigation/admin/2020/33-10906.pdf>.

[[3]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftnref3) *See, e.g.,* CFA Institute, "Payment for Order Flow in the United Kingdom" at 1 (2016), *available at* <https://www.cfainstitute.org/-/media/documents/article/position-paper/payment-for-order-flow-united-kingdom.ashx>.

[[4]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftnref4) *See* Joint CSA/IIROC Consultation Paper 23-406, "Internalization within the Canadian Equity Market" at 8 (March 12, 2019) ("UMIR 6.4 requires that trades by marketplace participants and related entities, subject to some exceptions, are executed on a marketplace. The main policy objectives of this provision are to strengthen liquidity, support price discovery and contribute to transparency. UMIR 6.4 is relevant to internalization in the context that in jurisdictions such as the United States, the execution of retail orders can occur off-marketplace. This notable difference is a contributing factor in how the Canadian market has evolved and is a consideration in our review and discussion of any future policy work."), *available at* <https://www.osc.ca/sites/default/files/pdfs/irps/csa_20190312_internalization-within-the-canadian-equity-market.pdf>.

[[5]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftnref5) *See *Cboe Global Markets, *available at* <https://www.cboe.com/us/equities/market_statistics/historical_market_volume/> (providing downloads of historical reported volume in NMS stocks by all self-regulatory organizations) ("SRO Volume Data"); *see* FINRA OTC (Non-ATS)Transparency Data, *available at* <https://otctransparency.finra.org/otctransparency/OtcDownload> (providing downloads of historical reported volume in NMS stocks by FINRA members) ("FINRA Member Volume Data").

[[6]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftnref6) *See *Citadel Securities,"Equities & Options," available at <https://www.citadelsecurities.com/products/equities-and-options/>.

[[7]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftnref7) *See *supra, note 5, SRO Volume Data and FINRA Member Volume Data.

[[8]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftnref8) *See *Reddit, "wallstreetbets," *available at* <https://www.reddit.com/r/wallstreetbets/>.

[[9]](https://www.sec.gov/news/testimony/gensler-testimony-20210505?utm_medium=email&utm_source=govdelivery#_ftnref9) *See *DTCC, "SIFMA, ICI and DTCC Leading Effort to Shorten U.S. Securities Settlement Cycle to T+1, Collaborating with the Industry on Next Steps" (April 28, 2021), *available at* <https://www.dtcc.com/news/2021/april/28/sifma-ici-and-dtcc-leading-effort-to-shorten-us-securities-settlement-cycle-to-t1>.
